@@ -3,7 +3,6 @@
 ######################################################################
 
 package Verilog::Netlist::Module;
-use Class::Struct;
 
 use Verilog::Netlist;
 use Verilog::Netlist::ContAssign;
@@ -17,7 +16,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::Module::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.240';
+$VERSION = '3.241';
 
 structs('new',
 	'Verilog::Netlist::Module::Struct'
@@ -429,10 +428,6 @@ See also Verilog::Netlist::Subclass for additional accessors and methods.
 
 =over 4
 
-=item $self->autos
-
-Updates the AUTOs for the module.
-
 =item $self->find_cell(I<name>)
 
 Returns Verilog::Netlist::Cell matching given name.
